# Copyright 2019 Akiomi Kamakura
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from pilgram2._1977 import _1977
from pilgram2.aden import aden
from pilgram2.amaro import amaro
from pilgram2.ashby import ashby
from pilgram2.brannan import brannan
from pilgram2.brooklyn import brooklyn
from pilgram2.charmes import charmes
from pilgram2.clarendon import clarendon
from pilgram2.crema import crema
from pilgram2.dogpatch import dogpatch
from pilgram2.earlybird import earlybird
from pilgram2.gingham import gingham
from pilgram2.ginza import ginza
from pilgram2.hefe import hefe
from pilgram2.helena import helena
from pilgram2.hudson import hudson
from pilgram2.inkwell import inkwell
from pilgram2.juno import juno
from pilgram2.kelvin import kelvin
from pilgram2.lark import lark
from pilgram2.lofi import lofi
from pilgram2.ludwig import ludwig
from pilgram2.maven import maven
from pilgram2.mayfair import mayfair
from pilgram2.moon import moon
from pilgram2.nashville import nashville
from pilgram2.perpetua import perpetua
from pilgram2.poprocket import poprocket
from pilgram2.reyes import reyes
from pilgram2.rise import rise
from pilgram2.sierra import sierra
from pilgram2.skyline import skyline
from pilgram2.slumber import slumber
from pilgram2.stinson import stinson
from pilgram2.sutro import sutro
from pilgram2.toaster import toaster
from pilgram2.valencia import valencia
from pilgram2.walden import walden
from pilgram2.willow import willow
from pilgram2.xpro2 import xpro2

__all__ = [
    "_1977",
    "aden",
    "amaro",
    "ashby",
    "brannan",
    "brooklyn",
    "charmes",
    "clarendon",
    "crema",
    "dogpatch",
    "earlybird",
    "gingham",
    "ginza",
    "hefe",
    "helena",
    "hudson",
    "inkwell",
    "juno",
    "kelvin",
    "lark",
    "lofi",
    "ludwig",
    "maven",
    "mayfair",
    "moon",
    "nashville",
    "perpetua",
    "poprocket",
    "reyes",
    "rise",
    "sierra",
    "skyline",
    "slumber",
    "stinson",
    "sutro",
    "toaster",
    "valencia",
    "walden",
    "willow",
    "xpro2",
]



# Copyright 2019 Akiomi Kamakura
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from PIL.Image import Image


def or_convert(im: Image, mode: str) -> Image:
    """Converts image to mode if necessary

    Arguments:
        im: An input image.
        mode: A string. The requested mode.

    Returns:
        The output image.
    """

    return im if im.mode == mode else im.convert(mode)
